import React, {useEffect} from 'react';
import {
  View,
  StyleSheet,
  Dimensions,
  ScrollView,
  StatusBar,
} from 'react-native';
import {SafeAreaView, useSafeAreaInsets} from 'react-native-safe-area-context';
import Book from './components/Book';
import {book, config} from '../../redux/actions';
import {connect} from 'react-redux';
import Navbar from '../../components/Navbar';

const {height, width} = Dimensions.get('window');

function Product({route, book, getBook, grades, getAvailableForSell}) {
  const insets = useSafeAreaInsets();

  useEffect(() => {
    getAvailableForSell();
    getBook({id: route.params.id, vod: true});
  }, []);

  return (
    <SafeAreaView
      style={{flex: 1, paddingTop: insets.top, paddingBottom: insets.bottom}}>
      <Navbar
        headerOptions={{
          logo: false,
          menu: false,
          hamburgerMenu: false,
          title: '',
          bookmark: true,
          qr: false,
          back: true,
          bookmarkItem: {productId: book?.id},
        }}
      />
      <ScrollView
        contentContainerStyle={styles.contentContainerStyle}
        style={styles.container}
        scrollEnabled={book ? true : false}>
        <Book book={book} grades={grades} />
      </ScrollView>
    </SafeAreaView>
  );
}

const styles = StyleSheet.create({
  contentContainerStyle: {
    paddingBottom: 100,
  },
  container: {
    flexDirection: 'column',
    paddingVertical: 5,
    paddingHorizontal: 16,
  },
});

const mapStateToProps = state => ({
  book: state.book.info,
  grades: state.publicApi.grades,
});

const mapDispatchToProps = {
  getBook: book.info,
  getAvailableForSell: config.getAvailableForSell,
};

export default connect(mapStateToProps, mapDispatchToProps)(Product);
