import React, {useState, useEffect} from 'react';
import {View, ScrollView, Dimensions, LayoutAnimation} from 'react-native';
import {SafeAreaView, useSafeAreaInsets} from 'react-native-safe-area-context';
import {connect} from 'react-redux';
import {book, config} from '../../redux/actions';

//components
import Drawer from '../../components/Drawer';
import Header from './components/Header';
import Main from './components/Main';
import Navbar from '../../components/Navbar';

//style
import tw from 'tailwind-rn';

//variables
const {height} = Dimensions.get('window');

function Products({
  books,
  getBooks,
  grades,
  route,
  setFilterOptions,
  filterOptions,
  getFilters,
}) {
  const insets = useSafeAreaInsets();
  const [position, setPosition] = useState('100%');

  useEffect(() => {
    getFilters();
    getBooks({vod: true});
  }, []);

  const setBoxPosition = () => {
    LayoutAnimation.configureNext(LayoutAnimation.Presets.easeInEaseOut);
    setPosition(position === '100%' ? '0%' : '100%');
  };

  useEffect(() => {
    if (route?.params?.productType === 'دوره ویدئویی') {
      setFilterOptions({...filterOptions, productType: 'محصولات ویدیویی'});
    }
  }, [route]);

  return (
    <SafeAreaView
      style={{flex: 1, paddingTop: insets.top, paddingBottom: insets.bottom}}>
      <Navbar
        setBoxPosition={setBoxPosition}
        headerOptions={{
          logo: true,
          menu: false,
          hamburgerMenu: true,
          title: '',
          bookmark: false,
          qr: true,
          back: false,
        }}
      />
      <Drawer setBoxPosition={setBoxPosition} position={position} />
      <Header />
      <ScrollView contentContainerStyle={{paddingBottom: height / 2}}>
        <Main books={books} grades={grades} />
      </ScrollView>
    </SafeAreaView>
  );
}

const mapStateToProps = state => ({
  grades: state.publicApi.grades,
  books: state.book.list,
  filterOptions: state.book.filterOptions,
});

const mapDispatchToProps = {
  getBooks: book.list,
  setFilterOptions: book.setFilterOptions,
  getFilters: config.getFilters,
};

export default connect(mapStateToProps, mapDispatchToProps)(Products);
