import { View, Text, Platform, Pressable, Dimensions } from "react-native";
// import * as ImagePicker from "expo-image-picker";
import React from "react";
import { connect } from "react-redux";
import { file } from "../../../redux/actions";
import { useNavigation } from "@react-navigation/native";

//components
import Avatar from "../../../components/Avatar";

//style
import tw from "tailwind-rn";
import fontSize from "../../../constants/fontSize";
import Colors from "../../../constants/Colors";

//variables
const ios = Platform.OS === "ios";
const { width } = Dimensions.get("window");

const User = ({ user, mobile, theme, upload }) => {
  const [dropdown, setDropdown] = React.useState(true);
  const [image, setImage] = React.useState(null);
  // const [status, requestPermission] = ImagePicker.useMediaLibraryPermissions();
  const navigation = useNavigation();

  const pickImage = React.useCallback(async () => {
    // No permissions request is necessary for launching the image library
    // let result = await ImagePicker.launchImageLibraryAsync({
    //   mediaTypes: ImagePicker.MediaTypeOptions.Images,
    //   allowsEditing: true,
    //   aspect: [1, 1],
    //   quality: 1,
    // });

    // upload({ file: result, name: "file" });

    // if (!result.cancelled) {
    //   setImage(result.uri);
    // }
  }, [image, user]);

  React.useEffect(() => {
    if (!user) {
      navigation.navigate("Login");
    }
  }, [user]);

  return (
    <View style={tw(`w-full  ${ios ? "items-end" : ""}`)}>
      <Pressable
        style={tw(
          `w-full mt-2 mb-2 flex flex-row-reverse justify-between items-center`
        )}
        onPress={() => setDropdown(!dropdown)}
      >
        <View style={tw(`flex items-center flex-row-reverse`)}>
          <Avatar
            source={
              user?.picFileId
                ? `https://dnvn.ir/api/v1/file/${user?.picFileId}`
                : null
            }
            size={mobile ? width / 5.5 : width / 7}
            action={() => pickImage()}
          />
          <View style={tw(`flex mr-2 ${ios ? "items-end" : ""}`)}>
            <Text
              style={{
                fontSize: mobile ? fontSize.lg : fontSize.xl,
                color:
                  theme === "light"
                    ? Colors.theme1.gray20
                    : Colors.theme1.white,
                fontFamily: "Medium",
              }}
            >
              {(user?.firstName || " ") + " " + (user?.lastName || " ")}
            </Text>
            <Text
              style={{
                fontSize: mobile ? fontSize.tiny : fontSize.base,
                color:
                  theme === "light"
                    ? Colors.theme1.gray20
                    : Colors.theme1.white,
                fontFamily: "Light",
                marginTop: mobile ? 3 : 6,
                textAlign: "right",
              }}
            >
              {user?.cellphone}
            </Text>
          </View>
        </View>
        {/* <Svg
          xmlns="http://www.w3.org/2000/svg"
          width={24}
          height={24}
          style={{ transform: [{ rotate: dropdown ? "0deg" : "180deg" }] }}
        >
          <Path
            d="M6.08 15.82h11.84a1.077 1.077 0 0 0 .76-1.84L13.499 8.8a2.131 2.131 0 0 0-3.01 0l-1.97 1.97-3.21 3.21a1.082 1.082 0 0 0 .771 1.84Z"
            fill="#c6c6c6"
            data-name="vuesax/bold/arrow-down"
          />
        </Svg> */}
      </Pressable>
      {/* {dropdown ? (
        <View style={tw(`flex flex-col pr-16 ${ios ? "items-end" : " "}`)}>
          <Pressable
            style={tw(`flex  w-full ${mobile ? "mt-0" : "mt-4"}`)}
            onPress={() =>
              asyncAwesomeAlert("", "این قابلیت در حال توسعه است.", {
                confirmText : 'باشه',
                showCancelButton: false,
              })
            }
          >
            <View
              style={[
                tw(`flex items-center w-full pb-3 mb-3 flex-row-reverse pt-2`),
                {
                  borderTopWidth: 1,
                  borderColor:
                    Colors.theme1.grayE3 + (theme === "light" ? "" : "55"),
                },
              ]}
            >
              <Text
                style={{
                  fontSize: mobile ? fontSize.base : fontSize.xl,
                  fontFamily: "Medium",
                  color:
                    theme === "light"
                      ? Colors.theme1.gray20
                      : Colors.theme1.white,
                }}
              >
                افزودن حساب کاربری جدید
              </Text>
              <Text
                style={{
                  marginRight: 5,
                  marginTop: 3,
                  fontSize: fontSize.xl2,
                  fontFamily: "Medium",
                  color:
                    theme === "light"
                      ? Colors.theme1.gray20
                      : Colors.theme1.white,
                }}
              >
                +
              </Text>
            </View>
          </Pressable>
        </View>
      ) : null} */}
    </View>
  );
};

const mapStateToProps = (state) => ({
  user: state.user.status,
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme,
});

const mapDispatchToProps = {
  upload: file.upload,
};

export default connect(mapStateToProps, mapDispatchToProps)(User);
