import React, { useEffect } from "react";
import {
  View,
  Image,
  ActivityIndicator,
  Dimensions,
  StatusBar,
} from "react-native";
import AsyncStorage from "@react-native-async-storage/async-storage";
import { connect } from "react-redux";
import {
  blog,
  book,
  userProduct,
  publicApi,
  config,
} from "../../redux/actions";

import Logo from "../../assets/appLogo.png";

const { width } = Dimensions.get("window");

//style
import Colors from "../../constants/Colors";

function Splash({
  navigation,
  theme,
  isLogin,
  getBlogs,
  getBooks,
  userProducts,
  getUserProducts,
  setIsDark,
  getBottomNavigation,
  bottomNavigation,
}) {
  const [sendRequest, setSendRequest] = React.useState(false);
  React.useEffect(() => {
    StatusBar.setBarStyle(
      `${theme === "light" ? "dark" : "light"}-content`,
      true
    );
  }, [theme]);

  const getTheme = async () => {
    const theme = await AsyncStorage.getItem("theme");
    setIsDark(!theme ? "light" : theme);
  };

  useEffect(() => {
    getTheme();
    if (isLogin !== null) {
      if (isLogin === false) {
        setTimeout(() => {
          getBottomNavigation();
          navigation.reset({
            index: 0,
            routes: [{ name: "Login" }],
          });
        }, 700);
      } else {
        if (!sendRequest) {
          setSendRequest(true);
          getBottomNavigation();
          getUserProducts();
          getBlogs();
          getBooks({ vod: true });
        }

        if (bottomNavigation) {
          navigation.reset({
            index: 0,
            routes: [{ name: "Root" }],
          });
        }
      }
    }
  }, [isLogin, bottomNavigation, userProducts]);

  return (
    <View
      style={{
        justifyContent: "center",
        alignItems: "center",
        flex: 1,
        display: "flex",
        backgroundColor : 'white'
      }}
    >
      <View style={{ height: (width * 0.7 * 2) / 3 }}>
        <Image
          source={Logo}
          resizeMode="contain"
          style={{
            width: width * 0.7,
            flex: 1,
          }}
        />
      </View>
      <ActivityIndicator
        size={"large"}
        color={Colors.theme1.dark}
        style={{ marginTop: 20 }}
      />
    </View>
  );
}

const mapStateToProps = (state) => ({
  isLogin: state.user.status,
  userProducts: state.userProduct.list,
  theme: state.publicApi.theme,
  bottomNavigation: state.config.bottomNavigation,
});

const mapDispatchToProps = {
  getBlogs: blog.list,
  getBooks: book.list,
  getUserProducts: userProduct.list,
  setIsDark: publicApi.setIsDark,
  getBottomNavigation: config.getBottomNavigation,
};

export default connect(mapStateToProps, mapDispatchToProps)(Splash);
